@@ -13,8 +13,8 @@
 #' @return A data.frame with metrics computed at the patch level.
 #' @details The imported metrics describe the patches and have been computed
 #' from the different graphs created in the Graphab project.
-#' See more information in Graphab 2.6 manual:
-#' \url{https://sourcesup.renater.fr/www/graphab/download/manual-2.6-en.pdf}
+#' See more information in Graphab 2.8 manual:
+#' \url{https://sourcesup.renater.fr/www/graphab/download/manual-2.8-en.pdf}
 #' @export
 #' @author P. Savary
 #' @examples
@@ -28,38 +28,34 @@ get_graphab_metric <- function(proj_name, # character
   #########################################
   # Check for project directory path
   if(!is.null(proj_path)){
-    chg <- 1
-    wd1 <- getwd()
-    setwd(dir = proj_path)
+    if(!dir.exists(proj_path)){
+      stop(paste0(proj_path, " is not an existing directory or the path is ",
+                  "incorrectly specified."))
+    } else {
+      proj_path <- normalizePath(proj_path)
+    }
   } else {
-    chg <- 0
-    proj_path <- getwd()
+    proj_path <- normalizePath(getwd())
   }
 
   #########################################
   # Check for proj_name class
   if(!inherits(proj_name, "character")){
-    # Before returning an error, get back to initial working dir
-    if(chg == 1){setwd(dir = wd1)}
     stop("'proj_name' must be a character string")
-  } else if (!(paste0(proj_name, ".xml") %in% list.files(path = paste0("./", proj_name)))){
-    # Before returning an error, get back to initial working dir
-    if(chg == 1){setwd(dir = wd1)}
+  } else if (!(paste0(proj_name, ".xml") %in%
+               list.files(path = paste0(proj_path, "/", proj_name)))){
     stop("The project you refer to does not exist.
          Please use graphab_project() before.")
   }
 
   #########################################
   # Check for patches.csv
-  if(!file.exists(paste0("./", proj_name, "/patches.csv"))){
-    df <- foreign::read.dbf(file = paste0("./", proj_name, "/patches.dbf"))
+  if(!file.exists(paste0(proj_path, "/", proj_name, "/patches.csv"))){
+    df <- foreign::read.dbf(file = paste0(proj_path, "/",
+                                          proj_name, "/patches.dbf"))
   } else {
-    df <- utils::read.csv(file = paste0("./", proj_name, "/patches.csv"))
-  }
-
-  #########################################
-  if(chg == 1){
-    setwd(dir = wd1)
+    df <- utils::read.csv(file = paste0(proj_path, "/",
+                                        proj_name, "/patches.csv"))
   }
 
   return(df)
